// TODO add labels and units for all elemental properties
export const property_labels = {
    atomic_mass: [`Atomic Mass`, `u`],
    atomic_radius: [`Atomic Radius`, `Å`],
    boiling_point: [`Boiling Point`, `K`],
    covalent_radius: [`Covalent Radius`, `Å`],
    density: [`Density`, `g/cm³`],
    electron_affinity: [`Electron Affinity`, null],
    electronegativity: [`Electronegativity`, null],
    first_ionization: [`First Ionization Energy`, `eV`],
    melting_point: [`Melting Point`, `K`],
    // molar_heat: [`Molar Heat`, `J/(mol·K)`],
    n_shells: [`Number of Shells`, null],
    n_valence: [`Electron Valency`, null],
    number: [`Atomic Number`, null],
    shells: [`Electron Shell Occupations`, null],
    specific_heat: [`Specific Heat`, `J/(g K)`],
};
export const heatmap_keys = [
    `atomic_mass`,
    `atomic_radius`,
    `covalent_radius`,
    `electronegativity`,
    `density`,
    `boiling_point`,
    `melting_point`,
    `first_ionization`,
];
export const heatmap_labels = Object.fromEntries(heatmap_keys.map((key) => {
    const [label, unit] = property_labels[key] ?? [];
    if (!label)
        throw `Unexpected missing label ${label}`;
    return [label + (unit ? ` (${unit})` : ``), key];
}));
export const pretty_num = (num, precision = 2) => {
    if (num === null)
        return ``;
    if ((Math.abs(num) < 0.01 && Math.abs(num) > 0) || num > 1e6) {
        return num.toExponential(precision);
    }
    else {
        return parseFloat(num.toFixed(precision)).toLocaleString();
    }
};
export const category_counts = {
    actinide: 15,
    'alkali metal': 6,
    'alkaline earth metal': 6,
    'diatomic nonmetal': 7,
    lanthanide: 15,
    metalloid: 8,
    'noble gas': 7,
    'polyatomic nonmetal': 4,
    'post-transition metal': 12,
    'transition metal': 38,
};
export const categories = [
    `actinide`,
    `alkali metal`,
    `alkaline earth metal`,
    `diatomic nonmetal`,
    `lanthanide`,
    `metalloid`,
    `noble gas`,
    `polyatomic nonmetal`,
    `post-transition metal`,
    `transition metal`,
];
// prettier-ignore
export const elem_symbols = [`H`, `He`, `Li`, `Be`, `B`, `C`, `N`, `O`, `F`, `Ne`, `Na`, `Mg`, `Al`, `Si`, `P`, `S`, `Cl`, `Ar`, `K`, `Ca`, `Sc`, `Ti`, `V`, `Cr`, `Mn`, `Fe`, `Co`, `Ni`, `Cu`, `Zn`, `Ga`, `Ge`, `As`, `Se`, `Br`, `Kr`, `Rb`, `Sr`, `Y`, `Zr`, `Nb`, `Mo`, `Tc`, `Ru`, `Rh`, `Pd`, `Ag`, `Cd`, `In`, `Sn`, `Sb`, `Te`, `I`, `Xe`, `Cs`, `Ba`, `La`, `Ce`, `Pr`, `Nd`, `Pm`, `Sm`, `Eu`, `Gd`, `Tb`, `Dy`, `Ho`, `Er`, `Tm`, `Yb`, `Lu`, `Hf`, `Ta`, `W`, `Re`, `Os`, `Ir`, `Pt`, `Au`, `Hg`, `Tl`, `Pb`, `Bi`, `Po`, `At`, `Rn`, `Fr`, `Ra`, `Ac`, `Th`, `Pa`, `U`, `Np`, `Pu`, `Am`, `Cm`, `Bk`, `Cf`, `Es`, `Fm`, `Md`, `No`, `Lr`, `Rf`, `Db`, `Sg`, `Bh`, `Hs`, `Mt`, `Ds`, `Rg`, `Cn`, `Nh`, `Fl`, `Mc`, `Lv`, `Ts`, `Og`];
